import { DAppMetaData } from "../types/dAppMeta";
import type { WalletConfig, WalletInstance } from "../types/wallet";
import { Chain } from "@thirdweb-dev/chains";
import { ConnectParams, CreateAsyncStorage, SignerWallet, WalletConnectHandler } from "@thirdweb-dev/wallets";
import { Signer } from "ethers";
import { PropsWithChildren } from "react";
type NonNullable<T> = T extends null | undefined ? never : T;
type WalletConnectParams<I extends WalletInstance> = Parameters<I["connect"]>[0];
export type ConnectionStatus = "unknown" | "connected" | "disconnected" | "connecting";
type ConnectFnArgs<I extends WalletInstance> = undefined extends WalletConnectParams<I> ? [
    wallet: WalletConfig<I>,
    connectParams?: NonNullable<WalletConnectParams<I>>
] : [
    wallet: WalletConfig<I>,
    connectParams: NonNullable<WalletConnectParams<I>>
];
type ThirdwebWalletContextData = {
    address: string | undefined;
    chainId: number | undefined;
    wallets: WalletConfig[];
    signer?: Signer;
    activeWallet?: WalletInstance;
    activeWalletConfig?: WalletConfig;
    connect: <I extends WalletInstance>(...args: ConnectFnArgs<I>) => Promise<I>;
    disconnect: () => Promise<void>;
    connectionStatus: ConnectionStatus;
    setConnectionStatus: (status: ConnectionStatus) => void;
    createWalletInstance: <I extends WalletInstance>(Wallet: WalletConfig<I>) => I;
    createdWalletInstance?: WalletInstance;
    createWalletStorage: CreateAsyncStorage;
    switchChain: (chain: number) => Promise<void>;
    chainToConnect?: Chain;
    activeChain: Chain;
    setConnectedWallet: (wallet: WalletInstance, params?: ConnectParams<Record<string, any>>) => Promise<void>;
    /**
     * Get wallet config object from wallet instance
     */
    getWalletConfig: (walletInstance: WalletInstance) => WalletConfig | undefined;
    /**
     * Get the "wrapper wallet" ( safe/smart wallet ) of the given personal wallet instance
     */
    getWrapperWallet: (walletInstance: WalletInstance) => WalletInstance | undefined;
    activeChainSetExplicitly: boolean;
    clientId?: string;
    walletConnectHandler: WalletConnectHandler | undefined;
    personalWalletConnection: WalletConnectionSetup;
    isAutoConnecting: boolean;
};
export declare const ThirdwebWalletContext: import("react").Context<ThirdwebWalletContextData | undefined>;
export type WalletConnectionSetup = {
    signer: Signer | undefined;
    connectionStatus: ConnectionStatus;
    setConnectionStatus: (status: ConnectionStatus) => void;
    activeWallet: WalletInstance | undefined;
    createdWalletInstance: WalletInstance | undefined;
    activeWalletConfig: WalletConfig | undefined;
    createWalletInstance: <I extends WalletInstance>(walletConfig: WalletConfig<I>) => I;
    setConnectedWallet: (WalletInstance: WalletInstance, connectParams?: ConnectParams<Record<string, any>>, isAutoConnect?: boolean) => Promise<void>;
    switchChain: (chainId: number) => Promise<void>;
    connectWallet: <I extends WalletInstance>(...args: ConnectFnArgs<I>) => Promise<I>;
    disconnectWallet: () => Promise<void>;
    chainId: number | undefined;
    address: string | undefined;
};
export declare function ThirdwebWalletProvider(props: PropsWithChildren<{
    activeChain: Chain;
    supportedWallets: WalletConfig[];
    shouldAutoConnect?: boolean;
    createWalletStorage: CreateAsyncStorage;
    dAppMeta?: DAppMetaData;
    chains: Chain[];
    autoSwitch?: boolean;
    autoConnectTimeout?: number;
    clientId?: string;
    activeChainSetExplicitly: boolean;
    signerWallet?: WalletConfig<SignerWallet>;
}>): import("react/jsx-runtime").JSX.Element;
/**
 * @internal
 */
export declare function useWalletContext(): ThirdwebWalletContextData;
/**
 * Get WalletConnect handler instance
 */
export declare function useWalletConnectHandler(): WalletConnectHandler | undefined;
export {};
//# sourceMappingURL=thirdweb-wallet-provider.d.ts.map